((Drupal, once) => {
    Drupal.behaviors.discPersonalityTest = {
        attach: (context) => {
            let currentQuestionIndex = 0;
            const questions = once('personality-questions', '.q', context);
            const backBtn = once('back-button', '#backBtn', context)[0];
            const nextBtn = once('next-button', '#nextBtn', context)[0];
            const submitBtn = once('submit-button', '#submit', context)[0];
            const progressBar = once('progress-bar', '#progress-bar', context)[0];

            function updateNavigationButtons() {
                if (backBtn) backBtn.disabled = currentQuestionIndex === 0;
                if (nextBtn) nextBtn.disabled = currentQuestionIndex === questions.length - 1 || !checkSelectedInputs();
                if (submitBtn) submitBtn.disabled = !(currentQuestionIndex === questions.length - 1 && checkSelectedInputs());
            }

            function showQuestion(index) {
                questions.forEach(q => q.classList.add('hidden'));
                questions[index].classList.remove('hidden');
                updateNavigationButtons();
            }

            function checkSelectedInputs() {
                const currentQuestion = questions[currentQuestionIndex];
                return currentQuestion.querySelector('input[type="radio"][name$="most"]:checked') &&
                    currentQuestion.querySelector('input[type="radio"][name$="least"]:checked');
            }

            if (backBtn) {
                backBtn.addEventListener('click', () => {
                    if (currentQuestionIndex > 0) {
                        currentQuestionIndex--;
                        showQuestion(currentQuestionIndex);
                    }
                });
            }

            if (nextBtn) {
                nextBtn.addEventListener('click', () => {
                    if (currentQuestionIndex < questions.length - 1) {
                        currentQuestionIndex++;
                        showQuestion(currentQuestionIndex);
                    }
                });
            }

            once('radio-change', 'input[type="radio"]', context).forEach(input => {
                input.addEventListener('change', updateNavigationButtons);
            });

            if (submitBtn) {
                submitBtn.addEventListener('click', () => {
                    if (currentQuestionIndex === questions.length - 1 && checkSelectedInputs()) {
                        const finalResult = processForm();
                        fetch(Drupal.url('personality-test'), {
                            method: 'POST',
                            headers: { 'Content-Type': 'application/json' },
                            body: JSON.stringify({
                                'finalResult': {
                                    'Dominance (D)': finalResult.weightedScores.d2,
                                    'Influence (I)': finalResult.weightedScores.i2,
                                    'Steadiness (S)': finalResult.weightedScores.s2,
                                    'Conscientiousness (C)': finalResult.weightedScores.c2,
                                }
                            })
                        })
                            .then(response => response.json())
                            .then(data => {
                                console.log(data);
                                if (progressBar) {
                                    progressBar.style.width = '100%';
                                    document.querySelector('#progress-percentage').textContent = '100%';
                                }
                            })
                            .catch(error => console.error('Error:', error));
                    }
                });
            }

            updateNavigationButtons();
        }
    };
})(Drupal, once);
